# GeeTest CAPTCHA Mocks

Local reconstructions of GeeTest v4 CAPTCHA challenges for offline solver testing and mousse recording.

### Slide CAPTCHA Ready

Drag slider to align puzzle piece with notch cutout. All 3 animation styles supported.

Float Popup Bind

### Icon CAPTCHA TODO

Click icons in the correct order. Not yet implemented.

### Gobang CAPTCHA TODO

Connect-five game challenge. Not yet implemented.

### IconCrush CAPTCHA TODO

Match-3 icon crushing challenge. Not yet implemented.